# IMPORTANT (DEPRECATED)


This software has been rewritten in Go, so it is recommended to use
**[go-asterisk-banner](https://github.com/savsgio/go-asterisk-banner)**,
because it's maintained and has more performance

Thanks :wink:

##################################################################################

Baneador de IPs en Asterisk con soporte para SIP y PJSIP

Instalacion:

1) Ejecutar el comando (en la raiz del proyecto)

    - pip3 install py-asterisk-banner

Desinstalacion:

1) Ejecutar el comando

    - pip3 uninstall py-asterisk-banner

